@@ -238,7 +238,8 @@ class VariableClUpdateRepRev(Variable):
 
 class VariableClUpdateBranch(Variable):
     """
-    Ветка на которую будет обновляться репозиторий если -getbinpkg
+    Ветка на которую будет обновляться репозиторий если
+    не используется синхронизация по тэгам
     """
     value = Git.Reference.Master
 
@@ -449,7 +450,7 @@ class VariableClUpdateBranchName(Variable):
             Git.Reference.Update]
 
     def get(self):
-        if "getbinpkg" in self.Get('cl_features'):
+        if self.GetBool('cl_update_usetag_set'):
             return [Git.Reference.Tag for x in self.Get('cl_update_rep_name')]
         else:
             branch = self.Get('cl_update_branch')
@@ -1334,6 +1335,7 @@ class DataVarsUpdateProfile(SimpleDataVars):
             VariableClUpdateRepRev(section="update"),
             VariableClUpdateBranch(section="update"),
             VariableClUpdateBranchName(section="update"),
+            VariableClUpdateUsetagSet(section="update"),
             VariableClUpdateLaymanConfig(section="update"),
             VariableClUpdateLaymanStorage(section="update"),
             VariableClUpdateRepName(section="update"),
@@ -1734,15 +1736,15 @@ class VariableClUpdateWithBdepsSet(Variable):
     """
     Добавление --with-bdeps при вызове emerge
     """
-    type = "bool"
-    value = "off"
+    type = Variable.Types.Boolean
+    value = Variable.Off
 
 
 class VariableClUpdateWithBdepsOptSet(Variable):
     """
     Добавление --with-bdeps при вызове emerge (опция)
     """
-    type = "bool"
+    type = Variable.Types.Boolean
     opt = ["--with-bdeps"]
 
     def init(self):
@@ -1757,5 +1759,13 @@ class VariableClUpdateForceDepcleanSet(Variable):
     """
     Принудительный вызов depclean
     """
-    type = "bool"
-    value = "off"
+    type = Variable.Types.Boolean
+    value = Variable.Off
+
+
+class VariableClUpdateUsetagSet(Variable):
+    """
+    Использовать тэги при синхронизации репозиториев
+    """
+    type = Variable.Types.Boolean
+    value = Variable.On
